@@ -71,6 +71,12 @@ TDNFCliParseRepoListArgs(
     TDNF_REPOLISTFILTER* pnFilter
     );
 
+uint32_t
+TDNFCliParseRepoSyncArgs(
+    PTDNF_CMD_ARGS pCmdArgs,
+    PTDNF_REPOSYNC_ARGS* ppReposyncArgs
+    );
+
 uint32_t
 TDNFCliParseMode(
     const char* pszOutMode,
@@ -116,6 +122,11 @@ TDNFCliRefresh(
     PTDNF_CLI_CONTEXT pContext
 );
 
+void
+TDNFCliFreeRepoSyncArgs(
+    PTDNF_REPOSYNC_ARGS pReposyncArgs
+    );
+
 //Commands
 uint32_t
 TDNFCliAutoEraseCommand(
@@ -189,6 +200,12 @@ TDNFCliProvidesCommand(
     PTDNF_CMD_ARGS pCmdArgs
     );
 
+uint32_t
+TDNFCliRepoSyncCommand(
+    PTDNF_CLI_CONTEXT pContext,
+    PTDNF_CMD_ARGS pCmdArgs
+    );
+
 uint32_t
 TDNFCliUpdateInfoCommand(
     PTDNF_CLI_CONTEXT pContext,
